/**
* @author Andre Moreira, mourdok@gmail.com
*/
jQuery(document).ready(function($) {

	/**
	* @requires database.js
	*/
	var db = prepareDatabase(), password = "";

	setupDatabase(db);

	/**
	* @description Init
	*/
	setPassword(db);

	/**
	* @event
	*/
	$("img.generate_password").click(function() {

		$(this).fadeOut('slow').fadeIn('slow');

		$("p.my_CSS3_class").text($.fn.generate(password));

	});

	/**
	* @function
	* @public
	*
	* @param {Database} db
	*
	* @example
	* setPassword(db);
	*/
	function setPassword(db) {

		db.transaction(function(tx) {

			tx.executeSql("SELECT * FROM generator WHERE id = 1", [], function(tx, result) {

				password = result.rows.item(0)['password'];

			}, null);

		});

	}

	/**
	* @function
	* @public
	*
	* @example
	* $.fn.generate();
	*/
	$.fn.generate = function(password) {

		var patternLetterUpper = /A/m, patternLetter = /a/m, patternNumber = /1/m, patternSymbol = /!/m;

		while (patternLetterUpper.test(password)) { password = password.replace(/A/m, jQuery.fn._letter().toUpperCase()); }

		while (patternLetter.test(password)) { password = password.replace(/a/m, jQuery.fn._letter()); }

		while (patternNumber.test(password)) { password = password.replace(/1/m, jQuery.fn._number()); }

		while (patternSymbol.test(password)) { password = password.replace(/!/m, jQuery.fn._symbol()); }

		return password;

	}

	/**
	* @function
	* @private
	*
	* @returns {String}
	*
	* @memberOf $.fn.generate
	*
	* @example
	* $.fn._letter();
	*/
	$.fn._letter  = function() {

		var letter   = "q,w,e,r,t,y,u,i,o,p,a,s,d,f,g,h,j,k,l,z,x,c,v,b,n,m".split(",");

		return letter[Math.floor(Math.random() * letter.length)];

	}

	/**
	* @function
	* @private
	*
	* @returns {String}
	*
	* @memberOf $.fn.generate
	*
	* @example
	* $.fn._number();
	*/
	$.fn._number  = function() {

		var number   = "1,2,3,4,5,6,7,8,9,0".split(",");

		return number[Math.floor(Math.random() * number.length)];

	}

	/**
	* @function
	* @private
	*
	* @returns {String}
	*
	* @memberOf $.fn.generate
	*
	* @example
	* $.fn._symbol();
	*/
	$.fn._symbol  = function() {

		var symbol   = "!,@,#,$,%,&,*,(,),_,+,-,=,{,},|,[,],:,;,<,>,?,.,/".split(",");

		return symbol[Math.floor(Math.random() * symbol.length)];

	}

});
